pub struct PageTableFlags {}Implementations
Sourceimpl PageTableFlags
impl PageTableFlags
Sourcepub const exec fn PRESENT() -> res : usize
pub const exec fn PRESENT() -> res : usize
returns
({ 0b00000001usize }),Specifies whether the mapped frame or page table is loaded in memory.
Sourcepub const exec fn WRITABLE() -> res : usize
pub const exec fn WRITABLE() -> res : usize
returns
({ 0b00000010usize }),Controls whether writes to the mapped frames are allowed.
Sourcepub const exec fn USER() -> res : usize
pub const exec fn USER() -> res : usize
returns
({ 0b00000100usize }),Controls whether accesses from userspace (i.e. ring 3) are permitted.
Sourcepub const exec fn WRITE_THROUGH() -> res : usize
pub const exec fn WRITE_THROUGH() -> res : usize
returns
({ 0b00001000usize }),If this bit is set, a “write-through” policy is used for the cache, else a “write-back” policy is used.
Sourcepub const exec fn NO_CACHE() -> res : usize
pub const exec fn NO_CACHE() -> res : usize
returns
({ 0b00010000usize }),Disables caching for the pointed entry if cacheable.
Sourcepub const exec fn ACCESSED() -> res : usize
pub const exec fn ACCESSED() -> res : usize
returns
({ 0b00100000usize }),Whether this entry has been used for linear-address translation.
Sourcepub const exec fn DIRTY() -> res : usize
pub const exec fn DIRTY() -> res : usize
returns
({ 0b01000000usize }),Whether the memory area represented by this entry is modified.
Sourcepub const exec fn HUGE() -> res : usize
pub const exec fn HUGE() -> res : usize
returns
({ 0b10000000usize }),Only in the non-starting and non-ending levels, indication of huge page.
Sourcepub const exec fn GLOBAL() -> res : usize
pub const exec fn GLOBAL() -> res : usize
returns
({ 0b00000001_00000000usize }),Indicates that the mapping is present in all address spaces, so it isn’t flushed from the TLB on an address space switch.
Sourcepub const exec fn NO_EXECUTE() -> res : usize
pub const exec fn NO_EXECUTE() -> res : usize
returns
({ 1usize << 63 }),Forbid constute codes on the page. The NXE bits in EFER msr must be set.